=== modified file 'NEWS'
--- NEWS	2008-02-26 21:36:22 +0000
+++ NEWS	2008-03-01 04:27:02 +0000
@@ -1,3 +1,6 @@
+Feb 29
+* Add link-tree command
+
 Feb 25
 * Add hard-link support to cbranch
 

=== modified file '__init__.py'
--- __init__.py	2008-02-29 18:18:40 +0000
+++ __init__.py	2008-03-01 04:27:02 +0000
@@ -641,6 +641,29 @@
                       working_tree=not no_tree)
 
 
+class cmd_link_tree(BzrToolsCommand):
+    """Hardlink matching files to another tree.
+
+    Only files with identical content and execute bit will be linked.
+    """
+    takes_args = ['location']
+
+    def run(self, location):
+        from bzrlib import workingtree
+        from bzrlib.plugins.bzrtools.link_tree import link_tree
+        target_tree = workingtree.WorkingTree.open_containing(".")[0]
+        source_tree = workingtree.WorkingTree.open(location)
+        target_tree.lock_write()
+        try:
+            source_tree.lock_read()
+            try:
+                link_tree(target_tree, source_tree)
+            finally:
+                source_tree.unlock()
+        finally:
+            target_tree.unlock()
+
+
 commands = [
             cmd_baz_import,
             cmd_baz_import_branch,
@@ -653,6 +676,7 @@
             cmd_fetch_ghosts,
             cmd_graph_ancestry,
             cmd_import,
+            cmd_link_tree,
             cmd_multi_pull,
             cmd_patch,
             cmd_rspush,

=== modified file 'tests/test_link_tree.py'
--- tests/test_link_tree.py	2008-02-29 18:18:40 +0000
+++ tests/test_link_tree.py	2008-03-01 04:27:02 +0000
@@ -21,7 +21,8 @@
 
 from bzrlib.plugins.bzrtools.link_tree import link_tree
 
-class TestLinkTree(TestCaseWithTransport):
+
+class TestLinkTreeBase(object):
 
     def setUp(self):
         TestCaseWithTransport.setUp(self)
@@ -39,6 +40,9 @@
         child_stat = os.lstat(self.child_tree.abspath('foo'))
         return parent_stat.st_ino == child_stat.st_ino
 
+
+class TestLinkTree(TestLinkTreeBase, TestCaseWithTransport):
+
     def test_link_fails_if_modified(self):
         """If the file to be linked has modified text, don't link."""
         self.build_tree_contents([('child/foo', 'baz')])
@@ -61,3 +65,15 @@
         """If the file to be linked is unmodified, link"""
         link_tree(self.child_tree, self.parent_tree)
         self.assertTrue(self.hardlinked())
+
+
+class TestLinkTreeCommand(TestLinkTreeBase, TestCaseWithTransport):
+
+    def test_link_tree(self):
+        """Ensure the command works as intended"""
+        os.chdir('child')
+        self.parent_tree.unlock()
+        self.run_bzr('link-tree ../parent')
+        self.assertTrue(self.hardlinked())
+        # want teh addCleanup to work properly
+        self.parent_tree.lock_write()

